@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute Halstead complexity metrics
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -210,6 +210,21 @@ sub BUILD {
     $self->{n_distinct_operands}  = keys %{ $distinct{operands} };
 }
 
+
+sub dump {
+    my ($self) = @_;
+    printf "Total operators = %d, Total operands = %d\n", $self->n_operators, $self->n_operands;
+    printf "Distinct operators = %d, Distinct operands = %d\n", $self->n_distinct_operators, $self->n_distinct_operands;
+    printf "Program vocabulary = %d, Program length = %d\n", $self->prog_vocab, $self->prog_length;
+    printf "Estimated program length = %.3f\n", $self->est_prog_length;
+    printf "Program volume = %.3f\n", $self->volume;
+    printf "Program difficulty = %.3f\n", $self->difficulty;
+    printf "Program level = %.3f\n", $self->level;
+    printf "Program effort = %.3f\n", $self->effort;
+    printf "Time to program = %.3f\n", $self->time_to_program;
+    printf "Delivered bugs = %.3f\n", $self->delivered_bugs;
+}
+
 sub _is_operand {
     my $key = shift;
     return $key eq 'PPI::Token::Comment'
@@ -237,7 +252,7 @@ Perl::Metrics::Halstead - Compute Halstead complexity metrics
 
 =head1 VERSION
 
-version 0.0100
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -245,16 +260,7 @@ version 0.0100
 
   my $pmh = Perl::Metrics::Halstead->new(file => '/some/perl/code.pl');
 
-  printf "Total operators = %d, Total operands = %d\n", $pmh->n_operators, $pmh->n_operands;
-  printf "Distinct operators = %d, Distinct operands = %d\n", $pmh->n_distinct_operators, $pmh->n_distinct_operands;
-  printf "Program vocabulary = %d, Program length = %d\n", $pmh->prog_vocab, $pmh->prog_length;
-  printf "Estimated program length = %.3f\n", $pmh->est_prog_length;
-  printf "Program volume = %.3f\n", $pmh->volume;
-  printf "Program difficulty = %.3f\n", $pmh->difficulty;
-  printf "Program level = %.3f\n", $pmh->level;
-  printf "Program effort = %.3f\n", $pmh->effort;
-  printf "Time to program = %.3f\n", $pmh->time_to_program;
-  printf "Delivered bugs = %.3f\n", $pmh->delivered_bugs;
+  $pmh->dump;
 
 =head1 DESCRIPTION
 
@@ -358,8 +364,16 @@ Create a new C<Perl::Metrics::Halstead> object given the B<file> argument.
 
 Process the given B<file> into the computed metrics.
 
+=head2 dump()
+
+  $pmh->dump();
+
+Print the computed metrics to C<STDOUT>.
+
 =head1 SEE ALSO
 
+The F<t/01-methods.t> file in this distribution.
+
 L<Moo>
 
 L<PPI::Document>
